-- ********************
-- * Plugin functions *
-- ********************

-- Functions: convertData, language/lang, loadData, saveData
--[[
converData
language/lang
loadData
saveData
--]]



Plugin = {};
Plugin.Scope = {
   Account = 1; -- Turbine.DataScope.Account
   Server = 2; -- Turbine.DataScope.Server
   Character = 3; -- Turbine.DataScope.Character
};

-- Plugin. Converts data to and from safe format. Mode = "To" / "From"
Plugin.convertData = function( data, mode )
   local type = type;

   if ( mode == "To" ) then

      local dataType = type( data );

      if ( dataType ~= "number" and dataType ~= "table" ) then
         return data;
      elseif ( dataType == "number" ) then
         local newData = "!!N" .. tostring( data );
         return newData;
      elseif ( dataType == "table" ) then
         local newData = {};
         for k, v in pairs( data ) do
            -- Key
            local t = type( k );
            local strKey;
            if ( t == "number" ) then
               strKey = Plugin.convertData( k, mode );
            else
               strKey = k;
            end

            -- Value
            t = type( v );
            if ( t == "number" or t == "table" ) then
               newData[strKey] = Plugin.convertData( v, mode );
            else
               newData[strKey] = v;
            end
         end
         return newData;
      end

      return "toString: unknown type: " .. dataType .. ". Mode: " .. mode .. ".";

   elseif ( mode == "From" ) then

      local dataType = type( data );

      if ( dataType ~= "table" and dataType ~= "string" ) then
         return data;
      elseif ( dataType == "string" ) then
         local markStart, markEnd = data:find( "!!N" );
         if ( markStart and markEnd and markStart == 1 ) then
            local newData = data:sub( markEnd + 1 );
            return getNumber( newData );
         else
            return data;
         end
      elseif ( dataType == "table" ) then
         local newData = {};
         for k, v in pairs( data ) do
            local orgKey = Plugin.convertData( k, mode );
            newData[orgKey] = Plugin.convertData( v, mode );
         end
         return newData;
      end

      return "toString: unknown type: " .. dataType .. ". Mode: " .. mode .. ".";

   else
      return "Plugin.data: wrong mode.";
   end
end

-- Plugin.
-- Returns code and ID of the game client's language using ISO 639-2 alpha-3 codes
Plugin.language = function()
   local langID = Turbine.Engine.GetLanguage();
   local langCode;
   if ( langID == 268435463 ) then
      langCode = "RUS";
   elseif ( langID == 268435460 ) then
      langCode = "GER";
   elseif ( langID == 268435459 ) then
      langCode = "FRE";
   elseif ( langID == 268435457 or langID == 2 ) then
      langCode = "ENG";
   end

   return langCode, langID;
end
Plugin.lang = Plugin.language;

Plugin.loadData = function( scope, fileName, onLoadFunction )
   local scope = Plugin.Scope[scope] or scope;
   return Turbine.PluginData.Load( scope, fileName, onLoadFunction );
end

Plugin.saveData = function( scope, fileName, data )
   local scope = Plugin.Scope[scope] or scope;
   Turbine.PluginData.Save( scope, fileName, data );
end
